@@ -166,7 +166,7 @@ void Tray::slotEditConnections()
 	if (!nm) return;
 	if (tdenetworkmanager_editor_dialog_count == 0) nm->loadConnectionInformation();
 
-	ConnectionEditorImpl* dlg = new ConnectionEditorImpl(this, NULL, TRUE, (WFlags)TQt::WDestructiveClose);
+	ConnectionEditorImpl* dlg = new ConnectionEditorImpl(this, NULL, true, (WFlags)TQt::WDestructiveClose);
 	dlg->show();
 }
 
@@ -256,15 +256,15 @@ void Tray::contextMenuAboutToShow (TDEPopupMenu* menu)
 					{
 						TQString actionName = TQString("new_connection_%1").arg(dev_comp_dev->deviceNode());
 						TQString menuCaption = TQString("%1").arg(dev_comp_dev->deviceNode());
-						if (menuCaption.contains("eth", FALSE) > 0)
+						if (menuCaption.contains("eth", false) > 0)
 						{
 							menuCaption = menuCaption.insert(0, "Wired Connection (");
 						}
-						else if (menuCaption.contains("wlan", FALSE) > 0)
+						else if (menuCaption.contains("wlan", false) > 0)
 						{
 							menuCaption = menuCaption.insert(0, "Wireless Connection (");
 						}
-						else if (menuCaption.contains("pan", FALSE) > 0)
+						else if (menuCaption.contains("pan", false) > 0)
 						{
 							menuCaption = menuCaption.insert(0, "Private Area Connection (");
 						}
