@@ -111,16 +111,16 @@ OpenVPNConfig::OpenVPNConfig(TQWidget* parent)
 	_openvpnWidget = new OpenVPNConfigWidget(this);
 	layout->addWidget(_openvpnWidget);
 
-	connect(_openvpnWidget->chkUseCipher, TQT_SIGNAL(toggled(bool)), _openvpnWidget->cboCipher, TQT_SLOT(setEnabled(bool)));
-	connect(_openvpnWidget->chkUseTLS, TQT_SIGNAL(toggled(bool)), _openvpnWidget->cboDirection, TQT_SLOT(setEnabled(bool)));
-	connect(_openvpnWidget->chkUseTLS, TQT_SIGNAL(toggled(bool)), _openvpnWidget->editTLSAuth, TQT_SLOT(setEnabled(bool)));
-	connect(_openvpnWidget->chkIPAdresses, TQT_SIGNAL(toggled(bool)), _openvpnWidget->routes, TQT_SLOT(setEnabled(bool)));
+	connect(_openvpnWidget->chkUseCipher, TQ_SIGNAL(toggled(bool)), _openvpnWidget->cboCipher, TQ_SLOT(setEnabled(bool)));
+	connect(_openvpnWidget->chkUseTLS, TQ_SIGNAL(toggled(bool)), _openvpnWidget->cboDirection, TQ_SLOT(setEnabled(bool)));
+	connect(_openvpnWidget->chkUseTLS, TQ_SIGNAL(toggled(bool)), _openvpnWidget->editTLSAuth, TQ_SLOT(setEnabled(bool)));
+	connect(_openvpnWidget->chkIPAdresses, TQ_SIGNAL(toggled(bool)), _openvpnWidget->routes, TQ_SLOT(setEnabled(bool)));
 
 	// add all Cipher modes to the Combobox
 	getCipherModes();
 
 	// switch to the right configuration interface when selecting the connection type
-	connect(_openvpnWidget->cboConnectionType, TQT_SIGNAL( activated(int)), _openvpnWidget->widgetStack, TQT_SLOT(raiseWidget(int)));
+	connect(_openvpnWidget->cboConnectionType, TQ_SIGNAL( activated(int)), _openvpnWidget->widgetStack, TQ_SLOT(raiseWidget(int)));
 	this->languageChange();
 }
 
@@ -180,7 +180,7 @@ void OpenVPNConfig::getCipherModes()
 		TDEProcess* cipherHelper = new TDEProcess();
 		cipherHelper->setUseShell(true, "/bin/sh");
 		*cipherHelper << TQString::fromLatin1("%1 --show-ciphers | awk '/^[A-Z][A-Z0-9]+-/ { print $1 }'").arg(openvpn);
-		connect (cipherHelper, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(receiveCipherData(TDEProcess*, char*, int)));
+		connect (cipherHelper, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQ_SLOT(receiveCipherData(TDEProcess*, char*, int)));
 		kdDebug() << "starting openvpn to get cipher modes" << endl;
 		if (!cipherHelper->start(TDEProcess::Block, TDEProcess::Stdout)) {
 			kdDebug() << "error starting openvpn" << endl;
